@@ -3,7 +3,7 @@ function(gr.crit = NULL, gr.cols = c("auto"),
 	freq.unit = "no frequency unit provided",
 	int.unit = "no intensity unit provided",
 	descrip = "no description provided",
-	format = "csv",
+	fileExt = "\\.(csv|CSV)$",
 	out.file = "mydata", debug = FALSE, ...) {
 		
 # Function to Read & Prep Spectroscopic Data
@@ -11,56 +11,53 @@ function(gr.crit = NULL, gr.cols = c("auto"),
 # Part of the ChemoSpec package
 # Bryan Hanson, DePauw University, Aug 2009
 
-# This function acts on all files in the working directory
+# This function acts on all files in the working directory with the specified extension
 
-# CSV files should have freq in column 1, absorbance/intensity in column 2.
-# There should be no column labels.
+# Files should have freq in column 1, absorbance/intensity in column 2.
+# There may or may not be a header (default is FALSE for read.table)
 
-# DX files can be parsed (see readJDX for limitations)
+# DX files can be parsed, but are handled separately (see readJDX for limitations)
 
 	if (!requireNamespace("R.utils", quietly = TRUE)) {
 		stop("You need to install package R.utils to use this function")
 		}
 
+	message("The default behavior of this function has changed as of July 2016.  See ?files2SpectraObject")
+	
 	if (is.null(gr.crit)) stop("No group criteria provided to encode data")
+	
+	DX = FALSE
+	if (grepl("(dx|DX|jdx|JDX)", fileExt)) DX <- TRUE
 
 	# First set up some common stuff
 	
-	if ((format == "csv") | (format == "csv2")) pat = "\\.(csv|CSV)$"
-	if (format == "dx") pat = "\\.(dx|DX|jdx|JDX)$"
-	files <- list.files(pattern = pat)
-	if ((format == "csv") | (format == "csv2")) {
-		files.noext <- substr(basename(files), 1, nchar(basename(files)) - 4)
-		}
-	if (format == "dx") files.noext <- substr(basename(files), 1, nchar(basename(files)) - 3)		
-	spectra <- list() # OK to initialize a list this way
+	files <- list.files(pattern = fileExt)
+	files.noext <- tools::file_path_sans_ext(files)
+
+	spectra <- list()
 	spectra$names <- files.noext
-			
-	
+
 	if (debug) message("\nfiles2SpectraObject is checking the first file")
-	if (format == "csv") temp <- read.csv(files[1], header = FALSE, ...)
-	if (format == "csv2") temp <- read.csv2(files[1], header = FALSE, ...)
-	if (format == "dx") {
-		temp <- readJDX(file = files[1], debug = debug)
-		}
+	if (!DX) temp <- read.table(files[1], ...)
+	if (DX) temp <- readJDX(file = files[1], debug = debug)
 
 	spectra$freq <- temp[,1]
 	if (class(spectra$freq) == "integer") {
-		message("\nConverting integer frequency values to numeric")
+		if (debug) message("\nConverting integer frequency values to numeric")
 		spectra$freq <- as.numeric(spectra$freq)
 		}
 	
-	spectra$data <- matrix(data = NA, nrow = length(files), ncol = length(spectra$freq))
+	spectra$data <- matrix(data = NA_real_, nrow = length(files), ncol = length(spectra$freq))
 	
-	# loop over all files (you have to read the whole file then grab
+	# Loop over all files (you have to read the whole file then grab
 	# just the part you want, i.e. the 2nd column)
 
 	if (debug) message("\nfiles2SpectraObject will now import your files")
+	
 	for (i in 1:length(files)) {
 		if (debug) cat("Importing file: ", files[i], "\n")
-		if (format == "csv") temp <- read.csv(files[i], header = FALSE, ...)
-		if (format == "csv2") temp <- read.csv2(files[i], header = FALSE, ...)
-		if (format == "dx") temp <- readJDX(files[i], debug = debug, ...)
+		if (!DX) temp <- read.table(files[i], ...)
+		if (DX) temp <- readJDX(files[i], debug = debug, ...)
 		spectra$data[i,] <- temp[,2]
 		}
 
