@@ -1,6 +1,7 @@
 hcaScores <-
 function(spectra, pca, scores = c(1:5),
-c.method = "complete", d.method = "euclidean", use.sym = FALSE, ...) {
+c.method = "complete", d.method = "euclidean", use.sym = FALSE,
+leg.loc = "topright",  ...) {
 
 # Function to carry out HCA on PCA scores
 # Part of the ChemoSpec package
@@ -23,7 +24,7 @@ c.method = "complete", d.method = "euclidean", use.sym = FALSE, ...) {
 	hclst <- hclust(distance, method = c.method)
 
 	d <- plotHCA(spectra = spectra, hclst = hclst, sub.title = sub.title,
-		use.sym = use.sym, ...)
+		use.sym = use.sym, leg.loc = leg.loc, ...)
 	L = list(hclst = hclst, dend = d)
 	return(L)
 	}
