@@ -26,7 +26,7 @@ plotSpectraJS <- function(spectra, browser = NULL, minify = TRUE) {
 		Names <- jsonlite::toJSON(paste(" ", spectra$names, sep = "  "))
 		Groups <- jsonlite::toJSON(spectra$groups)
 		Colors <- jsonlite::toJSON(spectra$colors)
-		Unit <- jsonlite::toJSON(spectra$unit)
+		xUnit <- jsonlite::toJSON(spectra$unit[1])
 		Desc <- jsonlite::toJSON(spectra$desc)
 		Dx <- jsonlite::toJSON(range(spectra$freq))
 		Dy <- jsonlite::toJSON(range(spectra$data))
@@ -47,7 +47,7 @@ plotSpectraJS <- function(spectra, browser = NULL, minify = TRUE) {
 		data4 <- paste("var Names = ", Names, sep = "")
 		data5 <- paste("var Groups = ", Groups, sep = "")
 		data6 <- paste("var Colors = ", Colors, sep = "")
-		data7 <- paste("var Unit = ", Unit, sep = "")
+		data7 <- paste("var xUnit = ", xUnit, sep = "")
 		data8 <- paste("var Desc = ", Desc, sep = "")
 		data9 <- paste("var Dx = ", Dx, sep = "")
 		data10 <- paste("var Dy = ", Dy, sep = "")
